@@ -46,7 +46,7 @@ def convert(json_path):
     coco_path_folder, coco_path_file = os.path.split(coco_path)
 
     print(coco_path_folder)
-    print(coco_path_folder)
+    print(coco_path_file)
 
     with open(coco_path) as reader:
         coco_json = json.load(reader)
@@ -78,13 +78,14 @@ def convert(json_path):
     annotate_list = coco_json["annotations"]
 
     for image in image_list:
-        img_name = os.path.splitext(image["file_name"])[0]
+        img_id = image["id"]
+        img_name = image["file_name"].split("/")[-1]
         for annotate in annotate_list:
-            annot_name = os.path.splitext(annotate["file_name"])[0]
-            if img_name == annot_name:
+            annot_id =annotate["image_id"]  # annotate["file_name"].split("/")[-1][:-4]
+            if img_id == annot_id:
                 img_cv = cv2.imread(
                     os.path.join(
-                        coco_path_folder, os.path.join("panoptic_masks", img_name + ".png")
+                        coco_path_folder, os.path.join("images", img_name + ".png")
                     )
                 )
                 if img_cv is None:
@@ -119,11 +120,11 @@ def convert(json_path):
                 img = cv2.cvtColor(img.reshape((H,W,C)), cv2.COLOR_RGB2BGR)
                 img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
                 pil_image = Image.fromarray(img)
-                
+
                 all_data.append({
-                    'image_name' : str(img_name) + ".png___save.png",
-                    'json_name' :  str(img_name) + ".png___pixel.json",
+                    'image_name' : str(img_name) + "___save.png",
+                    'json_name' :  str(img_name) + "___pixel.json",
                     'json' : out_json,
                     'image' : pil_image
                 })
-    return all_data
\ No newline at end of file
+    return all_data
